#ifndef __XMLIO_OBJECT__
#define __XMLIO_OBJECT__

namespace XMLIOSERVER
{
   class AbstractObject
   {
      public :

         const std::string& getId(void) const throw (XMLIOUndefinedValueException)
         {
            if (!hasId()) // Si l'identifiant de l'objet n'est pas défini.
               throw XMLIOSERVER::XMLIOUndefinedValueException("Appel de la méthode AbstractObject::getId invalide.");
            return (id);
         }

         bool hasId(void) const { return(IdDefined); }
         void resetId(void) { IdDefined = false ;}
         void setId(const std::string& _id) { id = _id ; IdDefined = true ;}

         bool operator==(const AbstractObject& other) const
         {
            // Si l'un ou l'autre des objets n'a pas d'identifiant, les objets ne sont pas "égaux".
            if(!this->hasId() || !other.hasId()) return false;
            return (id.compare(other.id) == 0);
         }

         std::string printId(void) const
         { if(hasId()) return (" id=\""+getId()+"\""); return (""); }

         virtual ~AbstractObject(void)
         {/* Ne rien faire de plus */}

      protected :

         AbstractObject(void) : IdDefined(false)
         {/* Ne rien faire de plus */}

         AbstractObject(const std::string& _id) : id(_id), IdDefined(true)
         {/* Ne rien faire de plus */}

      private :

         std::string id ;
         bool IdDefined ;

   };// class AbstractObject

}// namespace XMLIOSERVER

#endif // __XMLIO_OBJECT__
